#
# spec file for package diffutils
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           diffutils
Version:        3.11
Release:        1.2
Summary:        GNU diff Utilities
License:        GFDL-1.2-only AND GPL-3.0-or-later
Group:          Productivity/Text/Utilities
URL:            https://www.gnu.org/software/diffutils/
Source0:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/project/release-gpgkeys.php?group=diffutils&download=1#/%{name}.keyring
Provides:       diff = %{version}
Obsoletes:      diff < %{version}

%description
The GNU diff utilities find differences between files. diff is used to
make source code patches, for instance.

%lang_package

%prep
%autosetup -p1

%build
%configure \
  --with-packager="openSUSE" \
  --with-packager-bug-reports="https://bugs.opensuse.org/"
%make_build

%install
%make_install
%find_lang %{name}

%check
%if 0%{?qemu_user_space_build}
# Stack overflow tests are difficult to emulate, skip them
echo exit 77 > gnulib-tests/test-c-stack.sh
echo 'int main() { return 77; }' > gnulib-tests/test-sigsegv-catch-stackoverflow1.c
echo 'int main() { return 77; }' > gnulib-tests/test-sigsegv-catch-stackoverflow2.c
# This triggers a bug in qemu (bsc#1202260)
echo 'int main() { return 77; }' > gnulib-tests/test-free.c
%endif
%make_build check

%files
%license COPYING
%doc AUTHORS NEWS README THANKS
%{_bindir}/*
%{_infodir}/diffutils.info%{?ext_info}
%{_mandir}/man1/*.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%changelog
* Wed Feb  5 2025 Andreas Stieger <andreas.stieger@gmx.de>
- diffutils 3.11:
  * quote file names more consistently in diagnostics
  * diff now outputs more information when symbolic links differ
  * diff's --ignore-case (-i) and --ignore-file-name-case options
    now support multi-byte characters
  * diff now supports multi-byte characters when treating white
    space
  * In options like --expand-tabs (-t), --ignore-space-change (-b)
    and --ignore-tab-expansion (-E), diff now recognizes non-ASCII
    space characters and counts columns for non-ASCII characters.
  * cmp -bl no longer omits "M-" from bytes with the high bit set
    in single-byte locales like en_US.iso8859-1
  * cmp -i N and -n N no longer fail merely because N is enormous.
  * cmp -s no longer mishandles /proc files
  * diff -E no longer mishandles some input lines containing '\a',
    '\b', '\f', '\r', '\v', or '\0'.
  * diff -ly no longer mishandles non-ASCII input.
  * diff - A/B now works correctly when standard input is a
    directory, by reading a file named B in that directory.
  * diff no longer suffers from race conditions in some cases when
    comparing files in a mutating file system
* Mon May 22 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- diffutils 3.10:
  * cmp/diff can again work with file dates past Y2K38
  * diff -D no longer fails to output #ifndef lines
* Mon Jan 16 2023 Andreas Stieger <andreas.stieger@gmx.de>
- diffutils 3.9:
  * fixes for other platforms
* Wed Sep 14 2022 Andreas Schwab <schwab@suse.de>
- Skip gnulib test test-free under qemu emulation (bsc#1202260)
* Mon Sep 20 2021 Andreas Schwab <schwab@suse.de>
- Skip stack overflow tests under qemu emulation (bsc#1190046)
* Sat Aug  7 2021 Andreas Stieger <andreas.stieger@gmx.de>
- diffutils 3.8:
  * diff no longer treats a closed stdin as representing an absent
    file in usage like 'diff --new-file - foo <&-'
  * diff and related programs no longer get confused if stdin,
    stdout, or stderr are closed
  * cmp, diff and sdiff no longer treat negative command-line
    option-arguments as if they were large positive numbers
- drop gnulib-test-avoid-FP-perror-strerror.patch, upstream
- drop gnulib-c-stack.patch, equivalent change in c-stack
- remove deprecated texinfo packaging macros
* Mon Jul 19 2021 Andreas Schwab <schwab@suse.de>
- gnulib-c-stack.patch: c-stack: stop using SIGSTKSZ
* Mon Aug 31 2020 Bernhard Voelker <mail@bernhard-voelker.de>
- gnulib-test-avoid-FP-perror-strerror.patch: avoid false-positive
  error in gnulib tests 'test-perror2' and 'test-strerror_r',
  visible on armv7l.
* Thu Sep 19 2019 Ludwig Nussel <lnussel@suse.de>
- Do not recommend lang package. The lang package already has a
  supplements.
* Fri Jul  5 2019 Michel Normand <normand@linux.vnet.ibm.com>
- ignore make check error for diff --color as tracked by
  https://debbugs.gnu.org/cgi/bugreport.cgi?bug=36488
* Fri Jan  4 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.7:
  * bugfix - diff --strip-trailing-cr with a single CR byte in one
    input file would provoke an uninitialized memory read
  * diff --color now produces output compatible with less -R.
- Small packaging cleanups:
  * PIE is now default for whole distribution
  * xz is not needed as build dependency anymore
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Mon May 22 2017 mpluskal@suse.com
- Update to version 3.6:
  * When one file is a prefix of the other, cmp now appends the
    shorter file's size to the EOF diagnostic.
  * diff's default algorithm has been tweaked to deal better with
    larger files, reversing some of the changes made in
    diffutils-3.4.
- Define packager and bug reporting url
* Wed Feb 22 2017 mliska@suse.cz
- Update to a pre-release version (3.5.15):
  * remove big-file-performance.patch and gnulib-diffseq.patch
  * comment signature source as the release is not officially signed yet
* Wed Oct 26 2016 schwab@suse.de
- gnulib-diffseq.patch, big-file-performance.patch: Avoid performance
  regression on big files (bsc#1004991)
* Mon Aug 22 2016 astieger@suse.com
- Diffutils 3.5:
  * diff3 no longer malfunctions due to use-after-free
    [bug introduced in 3.4]
  * diff --color no longer colorizes when TERM=dumb
* Tue Aug  9 2016 mpluskal@suse.com
- Update to version 3.4
  * diff accepts two new options --color and --palette to generate
    and configure colored output.  --color takes an optional
    argument specifying when to colorize a line: --color=always,
  - -color=auto, --color=never.  --palette is used to configure
    which colors are used.
  * many bugfixes
- New -lang subpackage
- Drop no longer needed gnulib-perl522.patch
* Thu Feb  4 2016 mpluskal@suse.com
- Make building more verbose
- Move info page removal to preun
- Cleanup spec file with spec-cleaner
- Update provides/obsoletes
* Mon Jul  6 2015 coolo@suse.com
- add gnulib-perl522.patch from gnulib upstream
* Sat Jan  3 2015 meissner@suse.com
- build with PIE
* Fri Dec  6 2013 pth@suse.de
- Diffutils has a testsuite so run it.
* Fri Jun 21 2013 meissner@suse.com
- disable gpg key checking to avoid build cycles. will be
  done by source service
* Fri Apr  5 2013 meissner@suse.com
- add gpg key checking, keyring from savannah
* Fri Apr  5 2013 jslaby@suse.com
- Update to 3.3:
  * add --no-dereference
  * -N works with - (stdin) as input
  * many fixes
  * many cleanups (in docco too)
- remove: config-guess-sub-update.patch
- remove: diffutils-stdio.in.patch
* Mon Mar 25 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sat Feb  2 2013 schwab@suse.de
- Update config.guess/sub for aarch64
* Tue Jul 17 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Mon Feb 27 2012 jslaby@suse.de
- Update to 3.2:
  * diff: --ignore-file-name-case now applies at top level too
  * diff, sdiff: new option --ignore-trailing-space
  * maint: avoid new "make sytnax-check" failure
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sat Aug 13 2011 pth@suse.de
- Update to 3.1:
  + Bug fixes
  - diff no longer reports spurious differences merely because two
    entries in the same directory have names that compare equal in
    the current locale, or compare equal because --ignore-file-name-case
    was given.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 3.0:
  + Bug fixes
  - diff once again prints the required "\ No newline at end of
    file" line when at least one input lacks a newline-at-EOF and
    the final hunk plus context-length aligns exactly with the end
    of the newline-lacking file.
    [bug introduced between 2.8.7 and 2.9]
  + Changes in behavior
  - In context-style diffs, diff prints a portion of a preceding
    "function" line for each hunk, with --show-function-line=RE
    (-F) or --show-c-function (-p).  Now, it trims leading blanks
    from such lines before extracting a prefix.  This is useful
    especially when a function line is so far indented that the
    name itself would be truncated or not included in the
    limited-width substring that diff appends.
  - diff once again reports a difference with the diagnostic
    "Binary files A and B differ" when at least one of the files
    appears to be binary.  From 2.8.4 through diffutils-2.9, it
    printed "Files A and B differ".
- Changes from version 2.9:
  + New features
  - New diff option --suppress-blank-empty.
  - Bring back support for `diff -NUM', where NUM is a number,
    even when conforming to POSIX 1003.1-2001. This change
    reverts to the behavior of GNU diff 2.7 and earlier. This is
    a change only when conforming to POSIX 1003.1-2001; there is
    no effect when conforming to older POSIX versions.
  - sdiff now understands '1' and '2' as synonyms for 'l' and
    'r'.
  + Changes in behavior
  - sdiff and diff3 now invoke diff, not $(bindir)/diff
  + Administrivia
  - updated gnulib support
- Drop diffutils-no_binary_mode.patch: fixed upstream.
- Drop diffutils-2.8.1-i18n-0.2.patch: this doesn't apply anymore,
  the only reference I can guess about it goes back to 2004, and
  commit 8983b8d9 upstream is about handling multibyte characters
  in side-by-side format. So I'm assuming it's fixed. This also
  means we can drop the call to autoreconf.
- Drop diffutils-2.8.7-autoconf.patch: this is not needed anymore.
- Remove AutoReqProv: it's default now.
- Stop touching the main pages in %%build.
- Use %%configure and %%makeinstall macros.
* Fri Aug 20 2010 pth@novell.com
- Only do freopen if O_BINARY is true.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Feb 13 2010 rguenther@suse.de
- fix stack limit autoconf check
* Mon Dec  7 2009 jengelh@medozas.de
- enable parallel building
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
  * New diff option --suppress-blank-empty.
  * Bring back support for `diff -NUM', where NUM is a number,
    even when conforming to POSIX 1003.1-2001.  This change reverts to
    the behavior of GNU diff 2.7 and earlier.  This is a change only
    when conforming to POSIX 1003.1-2001; there is no effect when
    conforming to older POSIX versions.
    This change is in response to decisions taken in the January 2005
    Austin Group standardization meeting.  For more details, please see
    "Utility Syntax Guidelines" in the Minutes of the January 2005
    Meeting <http://www.opengroup.org/austin/docs/austin_239.html>.
  * sdiff now understands '1' and '2' as synonyms for 'l' and 'r'.
* Mon Nov 27 2006 rguenther@suse.de
- removed help2man BuildRequires again.  Instead prevent patches
  from invalidating the shipped manpages.
* Thu Oct  5 2006 mjancar@suse.cz
- readd help2man to BuildRequires (needed to build manpages)
* Fri Aug 11 2006 schwab@suse.de
- Update cmp patch [#198332].
* Mon Jul 24 2006 rguenther@suse.de
- diffutils does not need help2man.
* Fri Mar 10 2006 schwab@suse.de
- Fix output of EOF message when stdout is redirected to /dev/null.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 15 2004 schwab@suse.de
- Readd mbrtowc check [#45308].
* Tue May  4 2004 schwab@suse.de
- Update to diffutils 2.8.7.
* Tue Apr 13 2004 schwab@suse.de
- Update to diffutils 2.8.6.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Oct 15 2003 schwab@suse.de
- Update to diffutils 2.8.4.
* Mon May 12 2003 schwab@suse.de
- Add %%defattr.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Thu Sep  5 2002 schwab@suse.de
- Avoid rebuilding manpage [#18930].
* Tue Aug 20 2002 schwab@suse.de
- Add i18n patches.
* Mon Apr  8 2002 schwab@suse.de
- Update to diffutils 2.8.1.
  * Documentation fixes.
* Thu Mar 28 2002 schwab@suse.de
- Update to diffutils 2.8.
* Fri Oct  5 2001 schwab@suse.de
- Update to diffutils 2.7.2.
* Sat Jan 13 2001 schwab@suse.de
- Fix last change to close resource leaks.
* Sat Jan 13 2001 draht@suse.de
- tmpfile security problem fixed using mkstemp().
* Sun Dec  3 2000 schwab@suse.de
- diff: Fix a corner case in handling of directories.
- sdiff: Fix reading of split lines.
* Tue Oct 24 2000 schwab@suse.de
- Renamed from diff.
* Fri Sep  8 2000 schwab@suse.de
- Switch to BuildRoot.
- Add group tag.
- Use %%{_infodir}.
* Tue Jan 18 2000 schwab@suse.de
- /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Sep  8 1999 schwab@suse.de
- specfile cleanup
* Fri Dec 18 1998 ro@suse.de
- dont use m486 on alpha :-)
* Thu Jan  2 1997 florian@suse.de
  bug-fix for sdiff
